@@ -97,10 +97,16 @@ class DescribeInstancesRequest(RpcRequest):
 	def set_InstanceType(self,InstanceType):
 		self.add_query_param('InstanceType',InstanceType)
 
-	def get_Tags(self):
-		return self.get_query_params().get('Tags')
+	def get_EditionType(self):
+		return self.get_query_params().get('EditionType')
 
-	def set_Tags(self, Tags):
+	def set_EditionType(self,EditionType):
+		self.add_query_param('EditionType',EditionType)
+
+	def get_Tag(self):
+		return self.get_query_params().get('Tag')
+
+	def set_Tag(self, Tags):
 		for depth1 in range(len(Tags)):
 			if Tags[depth1].get('Value') is not None:
 				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tags[depth1].get('Value'))
